package com.yanzuoguang.util.vo;

import io.swagger.annotations.ApiModelProperty;

/**
 * 查询时分页请求接口
 * @author 颜佐光
 */
public interface PageSizeReq {
    /**
     * 获取记录开始的编号
     *
     * @return 返回记录开始的编号
     */
    @ApiModelProperty(value = "当前页的第一条序号", required = true, example = "1")
    int getPageStart();

    /**
     * 获取记录结束的编号
     *
     * @return 返回记录结束的编号
     */
    @ApiModelProperty(value = "当前页的最后一条序号", required = true, example = "20")
    int getPageEnd();

    /**
     * 获取当前第几页
     *
     * @return 返回当前页数，不能小于1
     */
    @ApiModelProperty(value = "第几页", required = true, example = "1", notes = "要查询第几页")
    int getPageIndex();

    /**
     * 获取每页条数
     *
     * @return 返回当前页数，不能小于1
     */
    @ApiModelProperty(value = "每页多少条", required = true, example = "20", notes = "每页包含多少条数据")
    int getPageSize();

    /**
     * 设置当前第几页
     *
     * @param index 设置当前第几页
     * @return 当前对象
     */
    @ApiModelProperty(value = "第几页", required = true, example = "1", notes = "要查询第几页")
    PageSizeReq setPageIndex(int index);

    /**
     * 设置每页数据量
     *
     * @param size 设置每页数据量
     * @return 当前对象
     */
    @ApiModelProperty(value = "每页多少条", required = true, example = "20", notes = "每页包含多少条数据")
    PageSizeReq setPageSize(int size);
}
